@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import discord
 from discord.ext import commands
 
@@ -25,11 +27,13 @@ class Simple(discord.ui.View):
                  PreviousButton: discord.ui.Button = discord.ui.Button(emoji=discord.PartialEmoji(name="\U000025c0")),
                  NextButton: discord.ui.Button = discord.ui.Button(emoji=discord.PartialEmoji(name="\U000025b6")),
                  PageCounterStyle: discord.ButtonStyle = discord.ButtonStyle.grey,
-                 InitialPage: int = 0) -> None:
+                 InitialPage: int = 0,
+                 ephemeral: bool = False) -> None:
         self.PreviousButton = PreviousButton
         self.NextButton = NextButton
         self.PageCounterStyle = PageCounterStyle
         self.InitialPage = InitialPage
+        self.ephemeral = ephemeral
 
         self.pages = None
         self.ctx = None
@@ -40,7 +44,11 @@ class Simple(discord.ui.View):
 
         super().__init__(timeout=timeout)
 
-    async def start(self, ctx: commands.Context, pages: list[discord.Embed]):
+    async def start(self, ctx: discord.Interaction|commands.Context, pages: list[discord.Embed]):
+        
+        if isinstance(ctx, discord.Interaction):
+            ctx = await commands.Context.from_interaction(ctx)
+
         self.pages = pages
         self.total_page_count = len(pages)
         self.ctx = ctx
@@ -57,7 +65,7 @@ class Simple(discord.ui.View):
         self.add_item(self.page_counter)
         self.add_item(self.NextButton)
 
-        self.message = await ctx.send(embed=self.pages[self.InitialPage], view=self)
+        self.message = await ctx.send(embed=self.pages[self.InitialPage], view=self, ephemeral=self.ephemeral)
 
     async def previous(self):
         if self.current_page == 0:
@@ -83,6 +91,7 @@ class Simple(discord.ui.View):
                                   color=discord.Colour.red())
             return await interaction.response.send_message(embed=embed, ephemeral=True)
         await self.next()
+        await interaction.response.defer()
 
     async def previous_button_callback(self, interaction: discord.Interaction):
         if interaction.user != self.ctx.author:
@@ -90,6 +99,8 @@ class Simple(discord.ui.View):
                                   color=discord.Colour.red())
             return await interaction.response.send_message(embed=embed, ephemeral=True)
         await self.previous()
+        await interaction.response.defer()
+
 
 
 class SimplePaginatorPageCounter(discord.ui.Button):
